% initial condition: u(0,x)=?
n = 100;
% advection speed: c=?
c = 1.0; 
% time increment: dt=?
dt = 0.0001; 

% ------------------------------------------------------ %
% fem: initialization
% n = length(u); 
Tn = 5;
t = 0:dt:(Tn*1/c); 
T = length(t);
dx = 1/n; 
x = 0:dx:n*dx; 

%　基底関数の行数
Nd = 4;

xa=n/10; xb=3*n/10; xc=6*n/10;

%- 係数ベクトル
U0=[zeros(xa,Nd); ones(xb,1) zeros(xb,Nd-1) ; zeros(xc,Nd)];
UU = [U0 zeros(n,Nd*(T-1))];

%- 要素境界上の値
u0 = [zeros(xa,2);ones(xb,2);zeros(xc,2)];
uu = [u0 zeros(n,2*(T-1))];

[M,C,K]=mk_MCKmatrix(Nd,dx);
for k=1:T-1
    for i=1:n
        if i==1 && k==1
            un = zeros(2,1);
        elseif i==1 && k~=1
            un = [uu(n,2*k-2);uu(1,2*k)];
        else
            un = uu(i-1:i,2*k);
        end
        [A1,A2]=mk_Avec(Nd,un);
        A2=zeros(Nd,1);
        UU(i,Nd*k+1:Nd*(k+1)) = UU(i,Nd*(k-1)+1:Nd*k)' + M\(-c*dt*(A1-C*UU(i,Nd*(k-1)+1:Nd*k)')+(1/2)*c^2*dt^2*(A2-K*UU(i,Nd*(k-1)+1:Nd*k)'));
        
        NVECR=legendre_basis(+1,Nd,0);
        NVECL=legendre_basis(-1,Nd,0);
        
        uu(i,2*k+2)=NVECR'*UU(i,Nd*k+1:Nd*(k+1))';
        uu(i,2*k+1)=NVECL'*UU(i,Nd*k+1:Nd*(k+1))';
    end
end

filename  = ['DG_AE_T','.avi']; 
writerObj = VideoWriter(filename,'Motion JPEG AVI'); 
writerObj.FrameRate = 20; %-- flame rate (slide/sec)
open(writerObj); %-- initialization of movie object

figure(1) 
Fnum=100; 
for tt=1:round(T/Fnum):T
    set(gcf, 'position', [100   100   480   480 ])     
    set(gcf, 'color',[1 1 1])  
    plot(x,[uu(1,2*tt-1);uu(:,2*tt)],'r'); hold on  %-uR
    plot(x,[uu(:,2*tt-1); uu(n,2*tt)],'b'); hold off %-uL
    hold off
    set(gca, 'position', [0.10  0.08  0.87  0.87])     
    set(gca, 'fontname', 'Arial', 'fontsize', 12)     
    xlim([0 1])     
    ylim([-0.5 1.5])      
    set(gca, 'YTick', -1:0.25:1)     
    frame = getframe(figure(1)); %-- get frame    
    writeVideo(writerObj,frame); %-- add frame to video obj
end
close(writerObj);


T1= length(0:dt:(1/c));

figure(2)
hold on
plot(x,[uu(1,1); uu(:,2)],'k');
plot(x,[uu(1,2*T1-1); uu(:,2*T1)],'r');
plot(x,[uu(1,2*T-1); uu(:,2*T)],'b');
hold off
print('DG_AE_T','-dmeta','-r1200')

%{
figure(3)
% plot(x,un(2*T-1,:)+un(2*T,:));
hold on
plot(x,[uu(1,2*T-1); uu(:,2*T)],'r');
plot(x,[uu(:,2*T-1); uu(n,2*T)],'b');
hold off
print('DG_AE_T2','-dmeta','-r1200')
%}